diff --git a/conf/cassandra.xml b/conf/cassandra.xml
index 57f905912f..d654cdcb1e 100644
--- a/conf/cassandra.xml
+++ b/conf/cassandra.xml
@@ -49,8 +49,8 @@
~ EndpointSnitch: Setting this to the class that implements
~ AbstractEndpointSnitch, which lets Cassandra know enough
~ about your network topology to route requests efficiently.
- ~ Out of the box, Cassandra provides org.apache.cassandra.locator.EndPointSnitch,
- ~ and PropertyFileEndPointSnitch is available in contrib/.
+ ~ Out of the box, Cassandra provides org.apache.cassandra.locator.EndpointSnitch,
+ ~ and PropertyFileEndpointSnitch is available in contrib/.
-->
org.apache.cassandra.locator.EndpointSnitch
diff --git a/contrib/pig/storage-conf.xml b/contrib/pig/storage-conf.xml
index 6acee1e857..9303c4feba 100644
--- a/contrib/pig/storage-conf.xml
+++ b/contrib/pig/storage-conf.xml
@@ -133,7 +133,7 @@
~ Out of the box, Cassandra provides org.apache.cassandra.locator.EndpointSnitch,
~ and PropertyFileEndpointSnitch is available in contrib/.
-->
- org.apache.cassandra.locator.EndPointSnitch
+ org.apache.cassandra.locator.EndpointSnitch
diff --git a/contrib/property_snitch/README.txt b/contrib/property_snitch/README.txt
index 38bc5429ab..09d941c89a 100644
--- a/contrib/property_snitch/README.txt
+++ b/contrib/property_snitch/README.txt
@@ -1,15 +1,15 @@
-PropertyFileEndPointSnitch
+PropertyFileEndpointSnitch
==========================
Cassandra's RackAwareStrategy can be used to have replication take
data-center and/or rack location into account when placing replicas. The
-ProperyFileEndPointSnitch allows you to make use of RackAwareStrategy by
+ProperyFileEndpointSnitch allows you to make use of RackAwareStrategy by
specifying node locations in a standard key/value properties file.
Properties File
---------------
-The EndPointSnitch expects to find a file on the classapth named
+The EndpointSnitch expects to find a file on the classapth named
cassandra-rack.properties in the following format:
\:=:
@@ -28,8 +28,8 @@ Installing
* Copy build/cassandra-propsnitch.jar to your Cassandra lib/
directory, or otherwise add it to the CLASSPATH
(see http://wiki.apache.org/cassandra/RunningCassandra)
- * Edit the EndPointSnitch element of storage-conf.xml to use
- org.apache.cassandra.locator.PropertyFileEndPointSnitch
+ * Edit the EndpointSnitch element of storage-conf.xml to use
+ org.apache.cassandra.locator.PropertyFileEndpointSnitch
* Create the cassandra-rack.properties in your classpath
(e.g. in your Cassandra conf/ directory)
* Optionally set ReplicaPlacementStrategy in cassandra.xml to
diff --git a/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitch.java b/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitch.java
similarity index 91%
rename from contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitch.java
rename to contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitch.java
index 91c178517a..bc3f7cc7a1 100644
--- a/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitch.java
+++ b/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitch.java
@@ -36,18 +36,18 @@ import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
- * PropertyFileEndPointSnitch
- *
- * PropertyFileEndPointSnitch is used by Digg to determine if two IP's are in the same
+ * PropertyFileEndpointSnitch
+ *
+ * PropertyFileEndpointSnitch is used by Digg to determine if two IP's are in the same
* datacenter or on the same rack.
- *
+ *
*/
-public class PropertyFileEndPointSnitch extends EndpointSnitch implements PropertyFileEndPointSnitchMBean {
+public class PropertyFileEndpointSnitch extends EndpointSnitch implements PropertyFileEndpointSnitchMBean {
/**
* A list of properties with keys being host:port and values being datacenter:rack
*/
private Properties hostProperties = new Properties();
-
+
/**
* The default rack property file to be read.
*/
@@ -57,13 +57,13 @@ public class PropertyFileEndPointSnitch extends EndpointSnitch implements Proper
* Whether to use the parent for detection of same node
*/
private boolean runInBaseMode = false;
-
+
/**
* Reference to the logger.
*/
- private static Logger logger_ = LoggerFactory.getLogger(PropertyFileEndPointSnitch.class);
+ private static Logger logger_ = LoggerFactory.getLogger(PropertyFileEndpointSnitch.class);
- public PropertyFileEndPointSnitch() throws ConfigurationException
+ public PropertyFileEndpointSnitch() throws ConfigurationException
{
reloadConfiguration();
try
@@ -125,7 +125,7 @@ public class PropertyFileEndPointSnitch extends EndpointSnitch implements Proper
@Override
public boolean isInSameDataCenter(InetAddress host, InetAddress host2)
throws UnknownHostException {
- if (runInBaseMode)
+ if (runInBaseMode)
{
return super.isInSameDataCenter(host, host2);
}
@@ -135,11 +135,11 @@ public class PropertyFileEndPointSnitch extends EndpointSnitch implements Proper
@Override
public boolean isOnSameRack(InetAddress host, InetAddress host2)
throws UnknownHostException {
- if (runInBaseMode)
+ if (runInBaseMode)
{
return super.isOnSameRack(host, host2);
}
- if (!isInSameDataCenter(host, host2))
+ if (!isInSameDataCenter(host, host2))
{
return false;
}
@@ -155,10 +155,10 @@ public class PropertyFileEndPointSnitch extends EndpointSnitch implements Proper
}
return configurationString.toString();
}
-
+
public void reloadConfiguration() throws ConfigurationException
{
- ClassLoader loader = PropertyFileEndPointSnitch.class.getClassLoader();
+ ClassLoader loader = PropertyFileEndpointSnitch.class.getClassLoader();
URL scpurl = loader.getResource(RACK_PROPERTY_FILENAME);
if (scpurl == null)
throw new ConfigurationException("unable to locate " + RACK_PROPERTY_FILENAME);
@@ -172,7 +172,7 @@ public class PropertyFileEndPointSnitch extends EndpointSnitch implements Proper
hostProperties = localHostProperties;
runInBaseMode = false;
}
- catch (IOException ioe)
+ catch (IOException ioe)
{
throw new ConfigurationException("Could not process " + rackPropertyFilename, ioe);
}
diff --git a/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitchMBean.java b/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitchMBean.java
similarity index 88%
rename from contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitchMBean.java
rename to contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitchMBean.java
index 8cfa4a09db..2d11314301 100644
--- a/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndPointSnitchMBean.java
+++ b/contrib/property_snitch/src/java/org/apache/cassandra/locator/PropertyFileEndpointSnitchMBean.java
@@ -23,18 +23,18 @@ import java.io.IOException;
import org.apache.cassandra.config.ConfigurationException;
/**
- * PropertyFileEndPointSnitchMBean
+ * PropertyFileEndpointSnitchMBean
*
- * PropertyFileEndPointSnitchMBean is the management interface for Digg's EndpointSnitch MBean
+ * PropertyFileEndpointSnitchMBean is the management interface for Digg's EndpointSnitch MBean
*
* @author Sammy Yu
*
*/
-public interface PropertyFileEndPointSnitchMBean {
+public interface PropertyFileEndpointSnitchMBean {
/**
* The object name of the mbean.
*/
- public static String MBEAN_OBJECT_NAME = "org.apache.cassandra.locator:type=EndPointSnitch";
+ public static String MBEAN_OBJECT_NAME = "org.apache.cassandra.locator:type=EndpointSnitch";
/**
* Reload the rack configuration
diff --git a/contrib/word_count/storage-conf.xml b/contrib/word_count/storage-conf.xml
index 62fb4d6a0d..9303c4feba 100644
--- a/contrib/word_count/storage-conf.xml
+++ b/contrib/word_count/storage-conf.xml
@@ -130,10 +130,10 @@
~ EndpointSnitch: Setting this to the class that implements
~ AbstractEndpointSnitch, which lets Cassandra know enough
~ about your network topology to route requests efficiently.
- ~ Out of the box, Cassandra provides org.apache.cassandra.locator.EndPointSnitch,
- ~ and PropertyFileEndPointSnitch is available in contrib/.
+ ~ Out of the box, Cassandra provides org.apache.cassandra.locator.EndpointSnitch,
+ ~ and PropertyFileEndpointSnitch is available in contrib/.
-->
- org.apache.cassandra.locator.EndPointSnitch
+ org.apache.cassandra.locator.EndpointSnitch
diff --git a/src/java/org/apache/cassandra/dht/BootStrapper.java b/src/java/org/apache/cassandra/dht/BootStrapper.java
index 62fae70fea..992fb336c9 100644
--- a/src/java/org/apache/cassandra/dht/BootStrapper.java
+++ b/src/java/org/apache/cassandra/dht/BootStrapper.java
@@ -141,7 +141,7 @@ public class BootStrapper
return maxEndpoint;
}
- /** get potential sources for each range, ordered by proximity (as determined by EndPointSnitch) */
+ /** get potential sources for each range, ordered by proximity (as determined by EndpointSnitch) */
Multimap getRangesWithSources(String table)
{
assert tokenMetadata.sortedTokens().size() > 0;
diff --git a/src/java/org/apache/cassandra/gms/GossipDigest.java b/src/java/org/apache/cassandra/gms/GossipDigest.java
index 5a9e2d51f7..63612a2fd0 100644
--- a/src/java/org/apache/cassandra/gms/GossipDigest.java
+++ b/src/java/org/apache/cassandra/gms/GossipDigest.java
@@ -27,7 +27,7 @@ import org.apache.cassandra.net.CompactEndpointSerializationHelper;
import java.net.InetAddress;
/**
- * Contains information about a specified list of EndPoints and the largest version
+ * Contains information about a specified list of Endpoints and the largest version
* of the state they have generated as known by the local endpoint.
*/
diff --git a/src/java/org/apache/cassandra/gms/GossipDigestAck2Message.java b/src/java/org/apache/cassandra/gms/GossipDigestAck2Message.java
index 322dd5fd0f..aaec1a6984 100644
--- a/src/java/org/apache/cassandra/gms/GossipDigestAck2Message.java
+++ b/src/java/org/apache/cassandra/gms/GossipDigestAck2Message.java
@@ -61,13 +61,13 @@ class GossipDigestAck2MessageSerializer implements ICompactSerializer epStateMap = EndPointStatesSerializationHelper.deserialize(dis);
+ Map epStateMap = EndpointStatesSerializationHelper.deserialize(dis);
return new GossipDigestAck2Message(epStateMap);
}
}
diff --git a/src/java/org/apache/cassandra/gms/GossipDigestAckMessage.java b/src/java/org/apache/cassandra/gms/GossipDigestAckMessage.java
index 9531040270..ea565e6501 100644
--- a/src/java/org/apache/cassandra/gms/GossipDigestAckMessage.java
+++ b/src/java/org/apache/cassandra/gms/GossipDigestAckMessage.java
@@ -73,10 +73,10 @@ class GossipDigestAckMessageSerializer implements ICompactSerializer epStateMap, DataOutputStream dos) throws IOException
{
@@ -151,7 +151,7 @@ class EndPointStatesSerializationHelper
{
if ( dis.available() == 0 )
{
- logger_.info("Remaining bytes zero. Stopping deserialization in EndPointState.");
+ logger_.info("Remaining bytes zero. Stopping deserialization in EndpointState.");
break;
}
// int length = dis.readInt();
diff --git a/src/java/org/apache/cassandra/gms/Gossiper.java b/src/java/org/apache/cassandra/gms/Gossiper.java
index a4ad446b31..179e61544c 100644
--- a/src/java/org/apache/cassandra/gms/Gossiper.java
+++ b/src/java/org/apache/cassandra/gms/Gossiper.java
@@ -111,7 +111,7 @@ public class Gossiper implements IFailureDetectionEventListener, IEndpointStateC
private long FatClientTimeout_;
private Random random_ = new Random();
- /* subscribers for interest in EndPointState change */
+ /* subscribers for interest in EndpointState change */
private List subscribers_ = new ArrayList();
/* live member set */
@@ -143,7 +143,7 @@ public class Gossiper implements IFailureDetectionEventListener, IEndpointStateC
FailureDetector.instance.registerFailureDetectionEventListener(this);
}
- /** Register with the Gossiper for EndPointState notifications */
+ /** Register with the Gossiper for EndpointState notifications */
public synchronized void register(IEndpointStateChangeSubscriber subscriber)
{
subscribers_.add(subscriber);
@@ -577,7 +577,7 @@ public class Gossiper implements IFailureDetectionEventListener, IEndpointStateC
* immediately mark it alive.
*
* @param ep endpoint
- * @param epState EndPointState for the endpoint
+ * @param epState EndpointState for the endpoint
* @param isKnownNode is this node familiar to us already (present in endpointStateMap)
*/
private void handleMajorStateChange(InetAddress ep, EndpointState epState, boolean isKnownNode)
@@ -914,7 +914,7 @@ public class Gossiper implements IFailureDetectionEventListener, IEndpointStateC
/*
* These digests have their maxVersion set to the difference of the version
- * of the local EndPointState and the version found in the GossipDigest.
+ * of the local EndpointState and the version found in the GossipDigest.
*/
List diffDigests = new ArrayList();
for ( GossipDigest gDigest : gDigestList )
diff --git a/src/java/org/apache/cassandra/gms/IEndpointStateChangePublisher.java b/src/java/org/apache/cassandra/gms/IEndpointStateChangePublisher.java
index ad73f3627d..dfcfda6006 100644
--- a/src/java/org/apache/cassandra/gms/IEndpointStateChangePublisher.java
+++ b/src/java/org/apache/cassandra/gms/IEndpointStateChangePublisher.java
@@ -27,13 +27,13 @@ public interface IEndpointStateChangePublisher
{
/**
* Register for interesting state changes.
- * @param subcriber module which implements the IEndPointStateChangeSubscriber
+ * @param subcriber module which implements the IEndpointStateChangeSubscriber
*/
public void register(IEndpointStateChangeSubscriber subcriber);
/**
* Unregister interest for state changes.
- * @param subcriber module which implements the IEndPointStateChangeSubscriber
+ * @param subcriber module which implements the IEndpointStateChangeSubscriber
*/
public void unregister(IEndpointStateChangeSubscriber subcriber);
}
diff --git a/src/java/org/apache/cassandra/gms/IEndpointStateChangeSubscriber.java b/src/java/org/apache/cassandra/gms/IEndpointStateChangeSubscriber.java
index b6cc5aa6a6..c05168f91d 100644
--- a/src/java/org/apache/cassandra/gms/IEndpointStateChangeSubscriber.java
+++ b/src/java/org/apache/cassandra/gms/IEndpointStateChangeSubscriber.java
@@ -21,7 +21,7 @@ package org.apache.cassandra.gms;
import java.net.InetAddress;
/**
- * This is called by an instance of the IEndPointStateChangePublisher to notify
+ * This is called by an instance of the IEndpointStateChangePublisher to notify
* interested parties about changes in the the state associated with any endpoint.
* For instance if node A figures there is a changes in state for an endpoint B
* it notifies all interested parties of this change. It is upto to the registered
diff --git a/src/java/org/apache/cassandra/locator/DatacenterEndpointSnitch.java b/src/java/org/apache/cassandra/locator/DatacenterEndpointSnitch.java
index 48ee337190..2615f6e9c8 100644
--- a/src/java/org/apache/cassandra/locator/DatacenterEndpointSnitch.java
+++ b/src/java/org/apache/cassandra/locator/DatacenterEndpointSnitch.java
@@ -34,17 +34,17 @@ import org.apache.cassandra.utils.XMLUtils;
import org.xml.sax.SAXException;
/**
- * DataCenterEndPointSnitch
+ * DataCenterEndpointSnitch
*
* This class basically reads the configuration and sets the IP Ranges to a
* hashMap which can be read later. this class also provides a way to compare 2
- * EndPoints and also get details from the same.
+ * Endpoints and also get details from the same.
*/
public class DatacenterEndpointSnitch extends AbstractEndpointSnitch
{
/**
- * This Map will contain the information of the EndPoints and its Location
+ * This Map will contain the information of the Endpoints and its Location
* (Datacenter and RAC)
*/
private Map> ipDC = new HashMap>();
diff --git a/src/java/org/apache/cassandra/locator/DatacenterShardStategy.java b/src/java/org/apache/cassandra/locator/DatacenterShardStategy.java
index dc7dbc53a8..2d432395f3 100644
--- a/src/java/org/apache/cassandra/locator/DatacenterShardStategy.java
+++ b/src/java/org/apache/cassandra/locator/DatacenterShardStategy.java
@@ -38,7 +38,7 @@ import org.apache.cassandra.thrift.ConsistencyLevel;
* other Datacenter.... For example if we have 5 nodes this stategy will make
* sure to make 2 copies out of 5 in other dataceneter.
*
- * This class also caches the EndPoints and invalidates the cache if there is a
+ * This class also caches the Endpoints and invalidates the cache if there is a
* change in the number of tokens.
*/
public class DatacenterShardStategy extends AbstractReplicationStrategy
@@ -62,8 +62,8 @@ public class DatacenterShardStategy extends AbstractReplicationStrategy
}
/**
- * This Method will get the required information of the EndPoint from the
- * DataCenterEndPointSnitch and poopulates this singleton class.
+ * This Method will get the required information of the Endpoint from the
+ * DataCenterEndpointSnitch and poopulates this singleton class.
*/
private synchronized void loadEndpoints(TokenMetadata metadata) throws IOException
{
@@ -111,7 +111,7 @@ public class DatacenterShardStategy extends AbstractReplicationStrategy
super(tokenMetadata, snitch);
if ((!(snitch instanceof DatacenterEndpointSnitch)))
{
- throw new IllegalArgumentException("DatacenterShardStrategy requires DatacenterEndPointSnitch");
+ throw new IllegalArgumentException("DatacenterShardStrategy requires DatacenterEndpointSnitch");
}
}
diff --git a/src/java/org/apache/cassandra/locator/RackAwareStrategy.java b/src/java/org/apache/cassandra/locator/RackAwareStrategy.java
index 2b8746bbed..77285f673b 100644
--- a/src/java/org/apache/cassandra/locator/RackAwareStrategy.java
+++ b/src/java/org/apache/cassandra/locator/RackAwareStrategy.java
@@ -40,7 +40,7 @@ public class RackAwareStrategy extends AbstractReplicationStrategy
{
super(tokenMetadata, snitch);
if (!(snitch instanceof EndpointSnitch))
- throw new IllegalArgumentException(("RackAwareStrategy requires EndPointSnitch."));
+ throw new IllegalArgumentException(("RackAwareStrategy requires EndpointSnitch."));
}
public ArrayList getNaturalEndpoints(Token token, TokenMetadata metadata, String table)
diff --git a/test/conf/cassandra.xml b/test/conf/cassandra.xml
index bc072d8ca1..6d64d5aef4 100644
--- a/test/conf/cassandra.xml
+++ b/test/conf/cassandra.xml
@@ -58,13 +58,13 @@
org.apache.cassandra.locator.RackUnawareStrategy
1
- org.apache.cassandra.locator.EndPointSnitch
+ org.apache.cassandra.locator.EndpointSnitch
org.apache.cassandra.locator.RackUnawareStrategy
5
- org.apache.cassandra.locator.EndPointSnitch
+ org.apache.cassandra.locator.EndpointSnitch
@@ -73,7 +73,7 @@
org.apache.cassandra.locator.RackUnawareStrategy
3
- org.apache.cassandra.locator.EndPointSnitch
+ org.apache.cassandra.locator.EndpointSnitch
diff --git a/test/system/__init__.py b/test/system/__init__.py
index eb1c89ca22..1986f48f24 100644
--- a/test/system/__init__.py
+++ b/test/system/__init__.py
@@ -142,7 +142,7 @@ class ThriftTester(BaseTester):
self.client.transport.close()
def define_schema(self):
- keyspace1 = Cassandra.KsDef('Keyspace1', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndPointSnitch',
+ keyspace1 = Cassandra.KsDef('Keyspace1', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndpointSnitch',
[
Cassandra.CfDef('Keyspace1', 'Standard1'),
Cassandra.CfDef('Keyspace1', 'Standard2'),
@@ -154,7 +154,7 @@ class ThriftTester(BaseTester):
Cassandra.CfDef('Keyspace1', 'Super4', column_type='Super', subcomparator_type='UTF8Type')
])
- keyspace2 = Cassandra.KsDef('Keyspace2', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndPointSnitch',
+ keyspace2 = Cassandra.KsDef('Keyspace2', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndpointSnitch',
[
Cassandra.CfDef('Keyspace2', 'Standard1'),
Cassandra.CfDef('Keyspace2', 'Standard3'),
@@ -162,12 +162,12 @@ class ThriftTester(BaseTester):
Cassandra.CfDef('Keyspace2', 'Super4', column_type='Super', subcomparator_type='TimeUUIDType'),
])
- keyspace3 = Cassandra.KsDef('Keyspace3', 'org.apache.cassandra.locator.RackUnawareStrategy', 5, 'org.apache.cassandra.locator.EndPointSnitch',
+ keyspace3 = Cassandra.KsDef('Keyspace3', 'org.apache.cassandra.locator.RackUnawareStrategy', 5, 'org.apache.cassandra.locator.EndpointSnitch',
[
Cassandra.CfDef('Keyspace3', 'Standard1'),
])
- keyspace4 = Cassandra.KsDef('Keyspace4', 'org.apache.cassandra.locator.RackUnawareStrategy', 3, 'org.apache.cassandra.locator.EndPointSnitch',
+ keyspace4 = Cassandra.KsDef('Keyspace4', 'org.apache.cassandra.locator.RackUnawareStrategy', 3, 'org.apache.cassandra.locator.EndpointSnitch',
[
Cassandra.CfDef('Keyspace4', 'Standard1'),
Cassandra.CfDef('Keyspace4', 'Standard3'),
diff --git a/test/system/test_thrift_server.py b/test/system/test_thrift_server.py
index 0221099fb4..a0c2afc4df 100644
--- a/test/system/test_thrift_server.py
+++ b/test/system/test_thrift_server.py
@@ -949,7 +949,7 @@ class TestMutations(ThriftTester):
def test_system_keyspace_operations(self):
""" Test keyspace (add, drop, rename) operations """
# create
- keyspace = KsDef('CreateKeyspace', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndPointSnitch',
+ keyspace = KsDef('CreateKeyspace', 'org.apache.cassandra.locator.RackUnawareStrategy', 1, 'org.apache.cassandra.locator.EndpointSnitch',
[
CfDef('CreateKeyspace', 'CreateKsCf')
])
diff --git a/src/java/org/apache/cassandra/gms/EndpointState.java b/src/java/org/apache/cassandra/gms/EndpointState.java
index 0e66584e68..e047cb113f 100644
--- a/src/java/org/apache/cassandra/gms/EndpointState.java
+++ b/src/java/org/apache/cassandra/gms/EndpointState.java
@@ -28,7 +28,7 @@ import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* This abstraction represents both the HeartBeatState and the ApplicationState in an EndPointState
* instance. Any state for a given endpoint can be retrieved from this instance.
*/
@@ -37,7 +37,7 @@ public class EndpointState
private static ICompactSerializer serializer_;
static
{
- serializer_ = new EndPointStateSerializer();
+ serializer_ = new EndpointStateSerializer();
}
HeartBeatState hbState_;
@@ -154,9 +154,9 @@ public class EndpointState
}
-class EndPointStateSerializer implements ICompactSerializer
+class EndpointStateSerializer implements ICompactSerializer
{
- private static Logger logger_ = LoggerFactory.getLogger(EndPointStateSerializer.class);
+ private static Logger logger_ = LoggerFactory.getLogger(EndpointStateSerializer.class);
public void serialize(EndpointState epState, DataOutputStream dos) throws IOException
{
@@ -177,7 +177,7 @@ class EndPointStateSerializer implements ICompactSerializer
{
if ( Gossiper.MAX_GOSSIP_PACKET_SIZE - dos.size() < estimate )
{
- logger_.info("@@@@ Breaking out to respect the MTU size in EndPointState serializer. Estimate is {} @@@@", estimate);;
+ logger_.info("@@@@ Breaking out to respect the MTU size in EndpointState serializer. Estimate is {} @@@@", estimate);;
break;
}
@@ -28,7 +28,7 @@ import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
- * This abstraction represents both the HeartBeatState and the ApplicationState in an EndPointState
+ * This abstraction represents both the HeartBeatState and the ApplicationState in an EndpointState
* instance. Any state for a given endpoint can be retrieved from this instance.
*/